# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 6.1.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by core Perl only.  The format and even the
# name or existence of this file are subject to change without notice.  Don't
# use it directly.


return <<'END';
3400	4DB5
4E00	9FCC
FA0E	FA0F
FA11		
FA13	FA14
FA1F		
FA21		
FA23	FA24
FA27	FA29
20000	2A6D6
2A700	2B734
2B740	2B81D
END
